# -*- mode: python -*-
# -*- coding: utf-8 -*-

##############################################################################
#
# Gestion scolarite IUT
#
# Copyright (c) 1999 - 2021 Emmanuel Viennet.  All rights reserved.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
#   Emmanuel Viennet      emmanuel.viennet@viennet.net
#
##############################################################################

"""
Génération de la "sidebar" (marge gauche des pages HTML)
"""
from flask import url_for, g

import app.scodoc.sco_utils as scu
from app.scodoc import sco_preferences
from app.scodoc.sco_permissions import Permission


def sidebar_common(context, REQUEST=None):
    "partie commune à toutes les sidebar"
    authuser = REQUEST.AUTHENTICATED_USER
    params = {
        "ScoURL": scu.ScoURL(),
        "UsersURL": scu.UsersURL(),
        "NotesURL": scu.NotesURL(),
        "AbsencesURL": scu.AbsencesURL(),
        "LogoutURL": url_for("auth.logout"),
        "authuser": str(authuser),
    }
    H = [
        '<a class="scodoc_title" href="about">ScoDoc 8</a>',
        '<div id="authuser"><a id="authuserlink" href="%(ScoURL)s/Users/user_info_page">%(authuser)s</a><br/><a id="deconnectlink" href="%(LogoutURL)s">déconnexion</a></div>'
        % params,
        sidebar_dept(context, REQUEST),
        """<h2 class="insidebar">Scolarit&eacute;</h2>
 <a href="%(ScoURL)s" class="sidebar">Semestres</a> <br/> 
 <a href="%(NotesURL)s" class="sidebar">Programmes</a> <br/> 
 <a href="%(AbsencesURL)s" class="sidebar">Absences</a> <br/>
 """
        % params,
    ]

    if authuser.has_permission(Permission.ScoUsersAdmin) or authuser.has_permission(
        Permission.ScoUsersView
    ):
        H.append(
            """<a href="%(UsersURL)s" class="sidebar">Utilisateurs</a> <br/>""" % params
        )

    if authuser.has_permission(Permission.ScoChangePreferences):
        H.append(
            """<a href="%(ScoURL)s/edit_preferences" class="sidebar">Paramétrage</a> <br/>"""
            % params
        )

    return "".join(H)


def sidebar(context, REQUEST=None):
    "Main HTML page sidebar"
    # rewritten from legacy DTML code
    from app.scodoc import sco_abs
    from app.scodoc import sco_etud

    params = {
        "ScoURL": scu.ScoURL(),
        "SCO_USER_MANUAL": scu.SCO_USER_MANUAL,
    }

    H = ['<div class="sidebar">', sidebar_common(context, REQUEST)]

    H.append(
        """<div class="box-chercheetud">Chercher étudiant:<br/>
<form method="get" id="form-chercheetud" action="%(ScoURL)s/search_etud_in_dept">
<div><input type="text" size="12" id="in-expnom" name="expnom" spellcheck="false"></input></div>
</form></div>
<div class="etud-insidebar">
"""
        % params
    )
    # ---- s'il y a un etudiant selectionné:
    if "etudid" in REQUEST.form:
        etudid = REQUEST.form["etudid"]
        etud = sco_etud.get_etud_info(filled=1, etudid=etudid)[0]
        params.update(etud)
        params["fiche_url"] = url_for(
            "scolar.ficheEtud", scodoc_dept=g.scodoc_dept, etudid=etudid
        )
        # compte les absences du semestre en cours
        H.append(
            """<h2 id="insidebar-etud"><a href="%(fiche_url)s" class="sidebar">
    <font color="#FF0000">%(civilite_str)s %(nom_disp)s</font></a>
    </h2>
    <b>Absences</b>"""
            % params
        )
        if etud["cursem"]:
            params["nbabs"], params["nbabsjust"] = sco_abs.get_abs_count(
                etudid, etud["cursem"]
            )
            params["nbabsnj"] = params["nbabs"] - params["nbabsjust"]
            params["date_debut"] = etud["cursem"]["date_debut"]
            params["date_fin"] = etud["cursem"]["date_fin"]
            H.append(
                """<span title="absences du %(date_debut)s au %(date_fin)s">(1/2 j.)<br/>%(nbabsjust)s J., %(nbabsnj)s N.J.</span>"""
                % params
            )

        H.append("<ul>")
        if REQUEST.AUTHENTICATED_USER.has_permission(Permission.ScoAbsChange):
            H.append(
                """
<li>     <a href="%(ScoURL)s/Absences/SignaleAbsenceEtud?etudid=%(etudid)s">Ajouter</a></li>
<li>     <a href="%(ScoURL)s/Absences/JustifAbsenceEtud?etudid=%(etudid)s">Justifier</a></li>
<li>     <a href="%(ScoURL)s/Absences/AnnuleAbsenceEtud?etudid=%(etudid)s">Supprimer</a></li>
"""
                % params
            )
            if sco_preferences.get_preference(context, "handle_billets_abs"):
                H.append(
                    """<li>     <a href="%(ScoURL)s/Absences/listeBilletsEtud?etudid=%(etudid)s">Billets</a></li>"""
                    % params
                )
        H.append(
            """
<li>     <a href="%(ScoURL)s/Absences/CalAbs?etudid=%(etudid)s">Calendrier</a></li>
<li>     <a href="%(ScoURL)s/Absences/ListeAbsEtud?etudid=%(etudid)s">Liste</a></li>
</ul>
"""
            % params
        )
    else:
        pass  # H.append("(pas d'étudiant en cours)")
    # ---------
    H.append("</div><br/>&nbsp;")  # /etud-insidebar
    # Logo
    scologo_img = scu.icontag("scologo_img")
    H.append('<div class="logo-insidebar"><div class="logo-logo">%s<br/>' % scologo_img)
    H.append(
        """<a href="%(ScoURL)s/about" class="sidebar">A propos</a><br/>
<a href="%(SCO_USER_MANUAL)s" class="sidebar">Aide</a><br/>
</div></div>

</div> <!-- end of sidebar -->
"""
        % params
    )  # '
    #
    return "".join(H)


def sidebar_dept(context, REQUEST=None):
    """Partie supérieure de la marge de gauche"""
    infos = {
        "BASE0": REQUEST.BASE0,
        "DeptIntranetTitle": sco_preferences.get_preference(
            context, "DeptIntranetTitle"
        ),
        "DeptIntranetURL": sco_preferences.get_preference(context, "DeptIntranetURL"),
        "DeptName": sco_preferences.get_preference(context, "DeptName"),
        "ScoURL": scu.ScoURL(),
    }

    H = [
        """<h2 class="insidebar">Dépt. %(DeptName)s</h2>
 <a href="%(BASE0)s" class="sidebar">Accueil</a> <br/> """
        % infos
    ]
    if infos["DeptIntranetURL"]:
        H.append(
            '<a href="%(DeptIntranetURL)s" class="sidebar">%(DeptIntranetTitle)s</a> <br/>'
            % infos
        )
    # Entreprises pas encore supporté en ScoDoc8
    # H.append(
    #    """<br/><a href="%(ScoURL)s/Entreprises" class="sidebar">Entreprises</a> <br/>"""
    #    % infos
    # )
    return "\n".join(H)
